---
name: Bug Report
about: Create a bug report to help us improve radish
title: ''
labels: ''
assignees: ''

---

**Important notices**
Before you add a new report, we ask you kindly to acknowledge the following:

[-] I have read the contributing guide lines at https://github.com/radish-bdd/radish/blob/master/.github/CONTRIBUTING.md

[-] I have read and respect the code of conduct at https://github.com/radish-bdd/radish/blob/master/.github/CODE_OF_CONDUCT.md

[-] I have searched the existing issues and I'm convinced that mine is new.

**Describe the bug**
A clear and concise description of what the bug is.

**Environment and Version**
* OS (incl. terminal and shell used): ...
* Python Version: ...
* radish Version (`radish --version`): ...

**To Reproduce**
A clear and concise description of steps to reproduce the behavior
you are experiencing.
This might also include a minial Feature File and Step Implementations.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Relevant log files**
If applicable, information from log files supporting your claim.
Log files could be:
* text file with the radish console output
* generated report files

**Additional context**
Add any other context about the problem here.
